Welcome to MedUX's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
      development/setup.rst

.. automodule:: medux


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Install
=======
